@@ -13,14 +13,15 @@ class PacketTypes(enum.IntEnum):
 
 
 class SequenceFlags(enum.IntEnum):
-    CONTINUATION_SEGMENT = (0b00,)
-    FIRST_SEGMENT = (0b01,)
-    LAST_SEGMENT = (0b10,)
+    CONTINUATION_SEGMENT = 0b00
+    FIRST_SEGMENT = 0b01
+    LAST_SEGMENT = 0b10
     UNSEGMENTED = 0b11
 
 
 class SpacePacketHeader:
-    """This class encapsulates the space packet header. Packet reference: Blue Book CCSDS 133.0-B-2"""
+    """This class encapsulates the space packet header.
+    Packet reference: Blue Book CCSDS 133.0-B-2"""
 
     def __init__(
         self,
@@ -39,7 +40,8 @@ class SpacePacketHeader:
             than 11 bits, deciaml 2074 or hex 0x7ff
         :param source_sequence_count: Sequence counter, should not be larger than 0x3fff or
             decimal 16383
-        :param data_length: Should not be largen than 65535 bytes
+        :param data_length: Contains a length count C that equals one fewer than the length of the
+            packet data field. Should not be larger than 65535 bytes
         :param packet_version:
         :param secondary_header_flag:
         :param sequence_flags:
@@ -250,7 +252,7 @@ def parse_space_packets(
         return tm_list
     # Packet ID detected
     while True:
-        if current_idx + 1 >= len(concatenated_packets):
+        if current_idx + 6 >= len(concatenated_packets):
             break
         current_packet_id = (
             concatenated_packets[current_idx] << 8
@@ -277,8 +279,8 @@ def __handle_packet_id_match(
     tm_list: List[bytearray],
 ) -> (int, int):
     next_packet_len_field = (
-        concatenated_packets[current_idx + 4] | concatenated_packets[current_idx + 5]
-    )
+        concatenated_packets[current_idx + 4] << 8
+    ) | concatenated_packets[current_idx + 5]
     total_packet_len = get_total_space_packet_len_from_len_field(next_packet_len_field)
     # Might be part of packet. Put back into analysis queue as whole
     if total_packet_len > len(concatenated_packets):
