@@ -1,4 +1,5 @@
 import enum
+from .definitions import DEFAULT_MAX_TC_DATA_SIZE
 
 
 class PusVersion(enum.IntEnum):
@@ -17,6 +18,7 @@ class EcssConfKeys(enum.IntEnum):
     ECSS_TM_APID = 1
     PUS_TM_TYPE = 2
     PUS_TC_TYPE = 3
+    MAX_TC_PACKET_SIZE = 4
 
 
 __ECSS_DICT = {
@@ -24,6 +26,7 @@ __ECSS_DICT = {
     EcssConfKeys.PUS_TC_TYPE: PusVersion.PUS_C,
     EcssConfKeys.ECSS_TM_APID: 0x00,
     EcssConfKeys.ECSS_TC_APID: 0x00,
+    EcssConfKeys.MAX_TC_PACKET_SIZE: DEFAULT_MAX_TC_DATA_SIZE,
 }
 
 
@@ -57,3 +60,11 @@ def set_default_tc_apid(tc_apid: int):
 
 def get_default_tc_apid() -> int:
     return __ECSS_DICT[EcssConfKeys.ECSS_TC_APID]
+
+
+def set_max_tc_packet_size(max_len: int):
+    __ECSS_DICT[EcssConfKeys.MAX_TC_PACKET_SIZE] = max_len
+
+
+def get_max_tc_packet_size() -> int:
+    return __ECSS_DICT[EcssConfKeys.MAX_TC_PACKET_SIZE]
