@@ -11,7 +11,12 @@ from spacepackets.ccsds.spacepacket import (
     SPACE_PACKET_HEADER_SIZE,
 )
 from spacepackets.util import get_printable_data_string, PrintFormats
-from spacepackets.ecss.conf import get_default_tc_apid, PusVersion, get_pus_tc_version
+from spacepackets.ecss.conf import (
+    get_default_tc_apid,
+    PusVersion,
+    get_pus_tc_version,
+    get_max_tc_packet_size,
+)
 
 
 try:
@@ -159,7 +164,7 @@ class PusTelecommand:
         service: int,
         subservice: int,
         ssc=0,
-        app_data: bytearray = bytearray([]),
+        app_data: bytes = bytes([]),
         source_id: int = 0,
         pus_version: PusVersion = PusVersion.GLOBAL_CONFIG,
         ack_flags: int = 0b1111,
@@ -195,6 +200,10 @@ class PusTelecommand:
         if ssc > pow(2, 14):
             logger.warning("SSC invalid, setting to 0")
             ssc = 0
+        if len(app_data) > get_max_tc_packet_size():
+            logger.warning(
+                "Application data of PUS packet exceeds maximum allowed size"
+            )
         self.data_field_header = PusTcDataFieldHeader(
             service_type=service,
             service_subtype=subservice,
@@ -230,8 +239,9 @@ class PusTelecommand:
     def __str__(self):
         """Returns string representation of a class instance."""
         return (
-            f"TC[{self.data_field_header.service_type}, "
-            f"{self.data_field_header.service_subtype}] with SSC {self.space_packet_header.ssc}"
+            f"PUS TC[{self.data_field_header.service_type}, "
+            f"{self.data_field_header.service_subtype}], APID {self.apid:#05x}, "
+            f"SSC {self.space_packet_header.ssc}, Size {self.packet_len}"
         )
 
     @property
@@ -341,10 +351,10 @@ class PusTelecommand:
         return self.space_packet_header.packet_id
 
     @property
-    def app_data(self) -> bytearray:
+    def app_data(self) -> bytes:
         return self._app_data
 
-    def print(self, print_format: PrintFormats):
+    def print(self, print_format: PrintFormats = PrintFormats.HEX):
         """Print the raw command in a clean format."""
         packet = self.pack()
         print(
