@@ -111,7 +111,7 @@ class PusTelemetry:
     @classmethod
     def unpack(
         cls,
-        raw_telemetry: bytearray,
+        raw_telemetry: bytes,
         pus_version: PusVersion = PusVersion.GLOBAL_CONFIG,
     ) -> PusTelemetry:
         """Attempts to construct a generic PusTelemetry class given a raw bytearray.
@@ -174,8 +174,8 @@ class PusTelemetry:
     def __str__(self):
         return (
             f"PUS TM[{self.secondary_packet_header.service_id},"
-            f"{self.secondary_packet_header.subservice_id}] with message counter "
-            f"{self.secondary_packet_header.message_counter}"
+            f"{self.secondary_packet_header.subservice_id}], APID {self.apid:#05x}, MSG Counter "
+            f"{self.secondary_packet_header.message_counter}, Size {self.packet_len}"
         )
 
     def __repr__(self):
@@ -284,21 +284,25 @@ class PusTelemetry:
     def crc16(self) -> int:
         return self._crc16
 
-    def get_full_packet_string(self, print_format: PrintFormats) -> str:
+    def get_full_packet_string(
+        self, print_format: PrintFormats = PrintFormats.HEX
+    ) -> str:
         packet_raw = self.pack()
         return get_printable_data_string(
             print_format=print_format, data=packet_raw, length=len(packet_raw)
         )
 
-    def print_full_packet_string(self, print_format: PrintFormats):
+    def print_full_packet_string(self, print_format: PrintFormats = PrintFormats.HEX):
         """Print the full TM packet in a clean format."""
         print(self.get_full_packet_string(print_format=print_format))
 
-    def print_source_data(self, print_format: PrintFormats):
+    def print_source_data(self, print_format: PrintFormats = PrintFormats.HEX):
         """Prints the TM source data in a clean format"""
         print(self.get_source_data_string(print_format=print_format))
 
-    def get_source_data_string(self, print_format: PrintFormats) -> str:
+    def get_source_data_string(
+        self, print_format: PrintFormats = PrintFormats.HEX
+    ) -> str:
         """Returns the source data string"""
         return get_printable_data_string(
             print_format=print_format,
@@ -385,7 +389,7 @@ class PusTmSecondaryHeader:
 
     @classmethod
     def unpack(
-        cls, header_start: bytearray, pus_version: PusVersion
+        cls, header_start: bytes, pus_version: PusVersion
     ) -> PusTmSecondaryHeader:
         """Unpack the PUS TM secondary header from the raw packet starting at the header index.
         The user still needs to specify the PUS version because the version field is parsed
