@@ -8,7 +8,7 @@ class PrintFormats(enum.IntEnum):
 
 
 def get_printable_data_string(
-        print_format: PrintFormats, data: bytes, length: int = -1
+    print_format: PrintFormats, data: bytes, length: int = -1
 ) -> str:
     """Returns the TM data in a clean printable hex string format
     :return: The string
@@ -20,23 +20,23 @@ def get_printable_data_string(
         return f'hex [{data_to_print.hex(sep=",", bytes_per_sep=1)}]'
     elif print_format == PrintFormats.DEC:
         if len(data_to_print) == 0:
-            return 'dec []'
+            return "dec []"
         elif len(data_to_print) == 1:
-            return f'dec [{data_to_print[0]}]'
+            return f"dec [{data_to_print[0]}]"
         elif len(data_to_print) >= 2:
-            string_to_print = 'dec ['
+            string_to_print = "dec ["
             for idx in range(len(data_to_print) - 1):
-                string_to_print += f'{data_to_print[idx]},'
-            string_to_print += f'{data_to_print[length - 1]}]'
+                string_to_print += f"{data_to_print[idx]},"
+            string_to_print += f"{data_to_print[length - 1]}]"
             return string_to_print
     elif print_format == PrintFormats.BIN:
         if len(data_to_print) == 0:
-            return 'bin []'
+            return "bin []"
         elif len(data_to_print) == 1:
-            return f'bin [0:{data_to_print[0]:08b}]'
+            return f"bin [0:{data_to_print[0]:08b}]"
         elif len(data_to_print) >= 2:
-            string_to_print = 'bin [\n'
+            string_to_print = "bin [\n"
             for idx in range(len(data_to_print)):
-                string_to_print += f'{idx}:{data_to_print[idx]:08b}\n'
-            string_to_print += f']'
+                string_to_print += f"{idx}:{data_to_print[idx]:08b}\n"
+            string_to_print += f"]"
             return string_to_print
